﻿using System;
using System.Collections.Generic;
using PickerView.Controls;
using UIKit;

namespace PickerView.iOS.Renderers
{
    /// <summary>
    /// Picker View model class to display and capture the current entry.
    /// </summary>
    public class MyPickerView : UIPickerViewModel
    {
        private List<string> v_PickerArray;
        private UIColor v_TextColor;
        private PickerControl v_Picker;
        private int v_SelectedIndex;
        /// <summary>
        /// Gets or sets the index of the selected item.
        /// </summary>
        /// <value>The index of the selected item.</value>
        public int SelectedIndex
        {
            get { return v_SelectedIndex; }
            set
            {
                if (v_SelectedIndex != value)
                {
                    v_SelectedIndex = value;

                }
            }
        }

        /// <summary>
        /// Initializes a new instance of the MyPickerView class with the required details.
        /// </summary>
        /// <param name="picker">Picker.</param>
        /// <param name="data">Data.</param>
        /// <param name="selectedValue">Selected value.</param>
        /// <param name="textColor">Text color.</param>
        /// <param name="Font">Font.</param>
        /// <param name="FontSize">Font size.</param>
        public MyPickerView(PickerControl picker, List<string> data, string selectedValue, UIColor textColor,
                            string Font, nfloat FontSize, string FontName)
        {
            v_PickerArray = data;
            SelectedItem = selectedValue;
            v_TextColor = textColor;

            if (Font == null || Font == "") Font = FontName;
            v_Picker = picker;

            v_Picker.HeightRequest = 132f;

        }

        /// <summary>
        /// Gets the selected item in string format
        /// </summary>
        /// <value>The selected item.</value>
        public string SelectedItem { get; private set; }

        /// <summary>
        /// Gets the component count currently selected.
        /// </summary>
        /// <returns>The component count.</returns>
        /// <param name="pickerView">Picker view.</param>
        public override nint GetComponentCount(UIPickerView pickerView)
        {
            return 1;
        }

        /// <summary>
        /// Gets number of rows in current component.
        /// </summary>
        /// <returns>The rows in component.</returns>
        /// <param name="pickerView">Picker view.</param>
        /// <param name="component">Component.</param>
        public override nint GetRowsInComponent(UIPickerView pickerView, nint component)
        {
            return v_PickerArray.Count;
        }

        /// <summary>
        /// Overriden method is called when any row is selected
        /// </summary>
        /// <param name="pickerView">Picker view.</param>
        /// <param name="row">Row.</param>
        /// <param name="component">Component.</param>
        public override void Selected(UIPickerView pickerView, nint row, nint component)
        {

            SelectedItem = v_PickerArray[(int)row];
            v_Picker.SelectedValue = SelectedItem;

        }
        public override nfloat GetRowHeight(UIPickerView pickerView, nint component)
        {
            return 44f;
        }
        /// <summary>
        /// Overriden method to create the current view with required details.
        /// </summary>
        /// <returns>The view.</returns>
        /// <param name="pickerView">Picker view.</param>
        /// <param name="row">Row.</param>
        /// <param name="component">Component.</param>
        /// <param name="view">View.</param>
        public override UIView GetView(UIPickerView pickerView, nint row, nint component, UIView view)
        {
            var lbl = new UILabel();
            lbl.Text = v_PickerArray[(int)row];

            lbl.TextAlignment = UITextAlignment.Center;
            lbl.TextColor = v_TextColor;
            return lbl;
        }
    }
}
