﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using PickerView.Controls;
using PickerView.iOS.Renderers;
using UIKit;
using Xamarin.Forms;
using Xamarin.Forms.Platform.iOS;

[assembly: ExportRenderer(typeof(PickerControl), typeof(PickerControlRenderer))]
namespace PickerView.iOS.Renderers
{
    /// <summary>
    /// Picker control renderer class used to display the numbers and picks the data 
    /// from the range of values.
    /// </summary>
    public class PickerControlRenderer : ViewRenderer<PickerControl, UIPickerView>
    {
        private UIPickerView v_PickerView;
        private MyPickerView v_PickerModel;
        private List<string> v_PickerElements;
        /// <summary>
        /// element changed function of Picker control Renderer
        /// </summary>
        protected override void OnElementChanged(ElementChangedEventArgs<PickerControl> e)
        {
            base.OnElementChanged(e);

            if (e.NewElement == null) return;


            AddPickerControl();

        }

        /// <summary>
        /// Overriden OnElementPropertyChanged function. Called when any property is changed in View class
        /// </summary>
        /// <param name="sender">Sender.</param>
        /// <param name="e">E.</param>
        protected override void OnElementPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            base.OnElementPropertyChanged(sender, e);
            if (e.PropertyName == PickerControl.SelectedValueProperty.PropertyName)
            {
                int index = v_PickerElements.IndexOf(Element.SelectedValue, 0);
                v_PickerModel.SelectedIndex = index;
                v_PickerView.Select(index, 0, false);

            }
        }

        /// <summary>
        /// Adds the picker control to the view class.
        /// </summary>
        private void AddPickerControl()
        {
            v_PickerView = new UIPickerView();
            v_PickerElements = Element.ItemsSource.Cast<string>().ToList();

            v_PickerModel = new MyPickerView(Element, v_PickerElements.ToList(), "--",
                Element.TextColor.ToUIColor(),
                Element.Font.FontFamily,
                (nfloat)Element.FontSize, Element.FontName);

            v_PickerView.BackgroundColor = Element.BackgroundColor.ToUIColor();
            v_PickerView.Model = v_PickerModel;
            v_PickerView.DataSource = v_PickerModel;

            SetNativeControl(v_PickerView);

            string selected = Element.SelectedValue;
            if (!string.IsNullOrEmpty(selected))
            {
                int index = v_PickerElements.IndexOf(selected, 0);
                v_PickerModel.SelectedIndex = index;
                v_PickerView.Select(index, 0, false);
            }

        }
    }
}
