﻿using System;
using System.Collections;
using Xamarin.Forms;

namespace PickerView.Controls
{
    /// <summary>
    /// Custom Control calls for Picker control.
    /// </summary>
    public class PickerControl : View
    {

        #region Public Data

        /// <summary>
        /// The text color property.
        /// </summary>
        public static readonly BindableProperty TextColorProperty = BindableProperty.Create(nameof(TextColor),
            typeof(Color), typeof(PickerControl), Color.Black, BindingMode.OneWay);

        /// <summary>
        /// The font property.
        /// </summary>
        public static readonly BindableProperty FontProperty = BindableProperty.Create(nameof(Font), typeof(Font),
            typeof(PickerControl), Font.Default, BindingMode.OneWay);

        /// <summary>
        /// The font size property.
        /// </summary>
        public static readonly BindableProperty FontSizeProperty = BindableProperty.Create(nameof(FontSize),
            typeof(double), typeof(PickerControl), 12.0, BindingMode.OneWay);

        /// <summary>
        /// This is Bindable property to get the Pop up icon for different pages.
        /// </summary>
        public static readonly BindableProperty SelectedValueProperty = BindableProperty.Create(nameof(SelectedValue),
            typeof(string), typeof(PickerControl), "", BindingMode.TwoWay);

        /// <summary>
        /// The font name property.
        /// </summary>
        public static readonly BindableProperty FontNameProperty = BindableProperty.Create(nameof(FontName),
            typeof(string), typeof(PickerControl), "", BindingMode.TwoWay);

        #endregion

        #region Constructor

        #endregion

        #region Public Methods

        /// <summary>
        /// This property will access the bindable property ImageSourceProperty to get the image and display in Popup screen.
        /// </summary>
        public Color TextColor
        {
            get => (Color)GetValue(TextColorProperty);
            set => SetValue(TextColorProperty, value);
        }


        /// <summary>
        /// This property will access the bindable property ImageSourceProperty to get the image and display in Popup screen.
        /// </summary>
        public Font Font
        {
            get => (Font)GetValue(FontProperty);
            set => SetValue(FontProperty, value);
        }


        /// <summary>
        /// This property will access the bindable property ImageSourceProperty to get the image and display in Popup screen.
        /// </summary>
        public Double FontSize
        {
            get => (Double)GetValue(FontSizeProperty);
            set => SetValue(FontSizeProperty, value);
        }

        /// <summary>
        /// This property will access the bindable property FontNameProperty to get the font name from converter.
        /// </summary>
        public string FontName
        {
            get => (string)GetValue(FontNameProperty);
            set => SetValue(FontNameProperty, value);
        }

        /// <summary>
        /// Creating Item Source Property
        /// </summary>
        /// <param >The name of the BindableProperty </param>
        /// <param>The type of the property. </param>
        ///  <param>The type of the owning object </param>
        ///  <param>The default value for the property </param>
        /// <param>A delegate to be run when the value has changed.  </param>
        /// 
        public static readonly BindableProperty ItemsSourceProperty = BindableProperty.Create(
            nameof(ItemsSource),
            typeof(ICollection),
            typeof(PickerControl),
            null,
            BindingMode.OneWay);


        /// <summary>
        /// Holds the list of  ItemsSource
        /// </summary>
        public ICollection ItemsSource
        {
            get => (ICollection)GetValue(ItemsSourceProperty);
            set => SetValue(ItemsSourceProperty, value);
        }

        /// <summary>
        /// This property will access the bindable property ImageSourceProperty to get the image and display in Popup screen.
        /// </summary>
        public string SelectedValue
        {
            get => (string)GetValue(SelectedValueProperty);
            set => SetValue(SelectedValueProperty, value);
        }

        #endregion

    }
}
