﻿using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using PickerView.Settings;

namespace PickerView.ViewModel
{
    public class WeightManualEntryViewModel
    {

        #region Private Data
        private readonly string v_CurrentLanguageDecimalSeparator = CultureInfo.CurrentCulture.NumberFormat.NumberDecimalSeparator;
        private readonly List<string> v_MyVitalWeightDecimalValues = new List<string>()
        {
            Constants.EmptyValueForWeightAndBloodPressure,
            Constants.MyVitalWeightDecimalSelectedValue, ".1", ".2", ".3", ".4", ".5", ".6", ".7", ".8", ".9"
        };

        #endregion

        #region Public Data
        /// <summary>
        /// Holds list of possible weight range 
        /// </summary>
        public List<string> WeightRange { get; private set; }
        /// <summary>
        /// Holds list of possible decimal portion of weight range 
        /// </summary>
        public List<string> WeightDecimalRange { get; private set; }
        /// <summary>
        /// Hold currently / last saved saved weight
        /// </summary>
        public string WeightSelectedValue { get; set; } = string.Empty;

        /// <summary>
        /// Hold decimal portion of currently / last saved saved weight
        /// </summary>
        public string WeightDecimalSelectedValue { get; set; } = string.Empty;

        /// <summary>
        /// Holds day for which weight is going to be saved
        /// </summary>
        public string EntryDay { get; set; }

        /// <summary>
        /// Holds currently available weight unit
        /// </summary>
        public string WeightUnit { get; private set; }


        #endregion

        #region Constructor

        public WeightManualEntryViewModel()
        {
            InitializePickerData();
        }

        #endregion
        #region Private Methods

        /// <summary>
        /// Initialize data for all the pickers
        /// </summary>
        private void InitializePickerData()
        {
            List<string> myVitalWeightRange = new List<string>();
            myVitalWeightRange.Add(Constants.EmptyValueForWeightAndBloodPressure);

            myVitalWeightRange.AddRange(Enumerable.Range(0, Constants.MyVitalWeightLimitForKgs + 1).Select(xx => xx.ToString()).ToList());
            WeightSelectedValue = Constants.MyVitalDefaultWeightForKgs.ToString();


            WeightRange = myVitalWeightRange;

            //The list is initialized with "." as decimal separator by default. Replace the "." with decimal separator based on current culture.
            var myVitalWeightDecimalValList = v_MyVitalWeightDecimalValues.Select(s => s.Replace(".", v_CurrentLanguageDecimalSeparator)).ToList();
            WeightDecimalRange = myVitalWeightDecimalValList;
            WeightDecimalSelectedValue = Constants.MyVitalWeightDecimalSelectedValue.Replace(".", v_CurrentLanguageDecimalSeparator);
        }


        #endregion

    }
}
